/*
 * lilJudd
 * Copyright (C) 2024 moonleay
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package net.moonleay.lilJudd.data

import java.io.*
import java.util.*

object NewsManager {
    private const val foldername = "data"
    private const val filename = "news.nick"
    lateinit var shouldPost: String
    lateinit var title: String
    lateinit var news: String

    ///Load the needed credentials, generate a config if there is none
    fun load() {
        val folder = File(foldername)
        if (!folder.exists()) {
            save()
            return
        }
        val configFile = File(folder, filename)
        if (!configFile.exists()) {
            save()
            return
        }
        try {
            val input: InputStream = FileInputStream(foldername + File.separator + filename)
            val prop = Properties()
            prop.load(input)
            shouldPost = prop.getProperty("shouldPost")
            title = prop.getProperty("title")
            news = prop.getProperty("news")
            input.close()
        } catch (e: IOException) {
            e.printStackTrace()
        }
    }

    fun update(){
        val folder = File(foldername)
        if (!folder.exists()) {
            try {
                folder.mkdirs()
            } catch (e: IOException) {
                e.printStackTrace()
            }
        }
        val configFile = File(foldername + File.separator + filename)
        if (!configFile.exists()) {
            try {
                configFile.createNewFile()
            } catch (e: IOException) {
                e.printStackTrace()
            }
        }
        try {
            val output: OutputStream = FileOutputStream(foldername + File.separator + filename)
            val prop = Properties()
            prop.setProperty("shouldPost", shouldPost)
            prop.setProperty("title", title)
            prop.setProperty("news", news)
            prop.store(output, null)
            output.close()
        } catch (e: IOException) {
            e.printStackTrace()
        }
    }

    ///generate a new sample config
    private fun save() {
        val folder = File(foldername)
        if (!folder.exists()) {
            try {
                folder.mkdirs()
            } catch (e: IOException) {
                e.printStackTrace()
            }
        }
        val configFile = File(foldername + File.separator + filename)
        if (!configFile.exists()) {
            try {
                configFile.createNewFile()
            } catch (e: IOException) {
                e.printStackTrace()
            }
        }
        try {
            val output: OutputStream = FileOutputStream(foldername + File.separator + filename)
            val prop = Properties()
            prop.setProperty("shouldPost", "no")
            prop.setProperty("title", "empty")
            prop.setProperty("news", "empty")
            prop.store(output, null)
            output.close()

            shouldPost = "no"
            title = "empty"
            news = "empty"
        } catch (e: IOException) {
            e.printStackTrace()
        }
    }
}
